@@ -2,10 +2,11 @@
 Helper module to find common object usages in app, e.g. xml node.
 """
 
-import bs4
-import re
-import os
 import json
+import os
+import re
+
+import bs4
 from lxml import etree
 
 
@@ -32,7 +33,7 @@ def get_dashboard_nodes(xmlfiles):
             ):
                 findings.append((rootnode.getroot(), relative_filepath))
     except Exception as exception:
-        print("Exception while getting dashboard nodes: {}".format(exception))
+        print(f"Exception while getting dashboard nodes: {exception}")
 
     return findings
 
@@ -83,19 +84,20 @@ def unpack_absolute_path(paths_tuple):
     return absolute_paths
 
 
-def validate_imports(files, allowed_imports_set):
-    """ This function returns paths of files which have require/define statements present in the allowed imports set
+def validate_imports(files, bad_imports_set, risky_imports_set):
+    """This function returns paths of files which have require/define statements present in the bad_imports_set imports set
 
     @param:
     files <Array>: Array of file paths
-    allowed_imports_set <Set>: Set of file path imports
+    bad_imports_set <Set>: Set of bad file path imports
+    risky_imports_set <Set>: Set of risky file path imports
 
     returns
 
     improper_files <List>: A list of objects corresponding to files with bad imports
         Example: [
-            { '/file_one.js': ['import_one', 'import_two'] },
-            { '/file_two.js': ['import_three', 'import_four'] }
+            { '/file_one.js': [ { 'bad': ['bad_one'], 'risky': ['risky_one', 'risky_two'] }] },
+            { '/file_two.js': [ { 'bad': ['bad_two', 'bad_three'], 'risky': ['risky_three'] }] }
         ]
     """
     improper_files = []
@@ -104,13 +106,26 @@ def validate_imports(files, allowed_imports_set):
             with open(filepath, "r", encoding="utf-8") as my_file:
                 matches = get_imported_matches(my_file.read())
                 bad_imports_in_file = []
+                risky_imports_in_file = []
                 for match in matches:
-                    if match in allowed_imports_set:
+                    if match in bad_imports_set:
                         bad_imports_in_file.append(match)
-                if bad_imports_in_file:
-                    improper_files.append({filepath: bad_imports_in_file})
+                    elif match in risky_imports_set:
+                        risky_imports_in_file.append(match)
+                identified_files = None
+                if bad_imports_in_file and risky_imports_in_file:
+                    identified_files = {
+                        "bad": bad_imports_in_file,
+                        "risky": risky_imports_in_file,
+                    }
+                elif bad_imports_in_file:
+                    identified_files = {"bad": bad_imports_in_file}
+                elif risky_imports_in_file:
+                    identified_files = {"risky": risky_imports_in_file}
+                if identified_files:
+                    improper_files.append({filepath: identified_files})
     except Exception as exception:
-        print("Exception while validating imports {}".format(exception))
+        print(f"Exception while validating imports {exception}")
 
     return improper_files
 
@@ -122,8 +137,8 @@ def communicate_bad_import_message(reporter, file_list):
     reporter: <Reporter>: An object which reports messages in App Inspect
     file_list <List>: A list of objects corresponding to files with bad imports
         Example: [
-            { '/file_one.js': ['import_one', 'import_two'] },
-            { '/file_two.js': ['import_three', 'import_four'] }
+            { '/file_one.js': [ { 'bad': ['bad_one'], 'risky': ['risky_one', 'risky_two'] }] },
+            { '/file_two.js': [ { 'bad': ['bad_two', 'bad_three'], 'risky': ['risky_three'] }] }
         ]
 
     returns
@@ -132,13 +147,24 @@ def communicate_bad_import_message(reporter, file_list):
     """
     for file_object in file_list:
         source_file = next(iter(file_object))
-        bad_imports_list = file_object[source_file]
-        message = (
-            "Embed all your app's front-end JS dependencies in the /appserver directory. "
-            + "If you import files from Splunk Web, your app might fail when Splunk Web updates. "
-            + "Bad imports: {}"
-        ).format(bad_imports_list)
-        reporter.warn(message, source_file)
+        identified_files = file_object[source_file]
+        if "bad" in identified_files:
+            bad_imports_list = identified_files["bad"]
+            message = (
+                "Embed all your app's front-end JS dependencies in the /appserver directory. "
+                "If you import files from Splunk Web, your app might fail when Splunk Web updates "
+                f"in the future. Bad imports: {bad_imports_list}"
+            )
+            reporter.fail(message, source_file)
+        if "risky" in identified_files:
+            risky_imports_list = identified_files["risky"]
+            message = (
+                "Embed all your app's front-end JS dependencies in the /appserver directory. "
+                "If you import files from Splunk Web, your app might be at risk of failing "
+                "due to the removal of files when Splunk Web updates in the future. "
+                f"Risky imports: {risky_imports_list}"
+            )
+            reporter.warn(message, source_file)
 
 
 def get_imported_matches(file):
@@ -161,13 +187,13 @@ def get_imported_matches(file):
     ['jquery', 'underscore', 'splunkjs/mvc', 'util/console']
     """
     matches = []
-    pattern = re.compile(
-        r"(require|define)(\s)*\((\s)*\[[^\[]+\]|(require|define)(\s)*\((\n|.)*\)"
-    )
+    pattern = re.compile(r"(^|[\n\r\s]+)(require|define)\([^)\]]+(\]|\))")
     for matched_object in pattern.finditer(file):
         imported_matches = re.finditer(r"['\"]([^'\"]*)['\"]", matched_object.group())
         for imported in imported_matches:
-            matches.append(imported.group(1))
+            match = imported.group(1)
+            if match not in matches:
+                matches.append(match)
     return matches
 
 
@@ -225,7 +251,7 @@ def populate_set_from_json(file_path):
         for i in array_from_json:
             json_set.add(i)
     except Exception as exception:
-        print("Error while loading json to a set. {}".format(exception))
+        print(f"Error while loading json to a set. {exception}")
 
     return json_set
 
