@@ -5,19 +5,17 @@
 
 Ensure that all configuration files located in the **/default** folder are well formed and valid.
 """
-
-# Python Standard Library
 import collections
 import logging
 import os
 import re
 
-# Custom Libraries
-import splunk_appinspect
-from splunk_appinspect.splunk_defined_conf_file_list import SPLUNK_DEFINED_CONFS
-from splunk_appinspect import app_util
 from six import iteritems
 
+import splunk_appinspect
+from splunk_appinspect import app_util
+from splunk_appinspect.splunk_defined_conf_file_list import SPLUNK_DEFINED_CONFS
+
 report_display_order = 2
 logger = logging.getLogger(__name__)
 
@@ -43,8 +41,9 @@ def check_validate_no_duplicate_stanzas_in_conf_files(app, reporter):
         if len(linenos) > 1:
             for lineno in linenos:
                 reporter_output = (
-                    "Duplicate {} stanzas were found. " "File: {}, Line: {}."
-                ).format(key[1], key[0], lineno)
+                    f"Duplicate {key[1]} stanzas were found. "
+                    f"File: {key[0]}, Line: {lineno}."
+                )
                 reporter.fail(reporter_output, key[0], lineno)
 
 
@@ -62,8 +61,9 @@ def check_config_file_parsing(app, reporter, included_tags):
             conf = app.get_config(filename, dir=directory)
             for err, lineno, section in conf.errors:
                 reporter_output = (
-                    "{0} at line {1} in [{2}] of {3}. " "File: {4}, Line: {1}."
-                ).format(err, lineno, section, filename, file_path)
+                    f"{err} at line {lineno} in [{section}] of {filename}. "
+                    f"File: {file_path}, Line: {lineno}."
+                )
                 if err.startswith(("Duplicate stanza", "Repeat item")):
                     if "cloud" in included_tags:
                         reporter.warn(reporter_output, file_path, lineno)
@@ -101,14 +101,14 @@ def check_no_default_stanzas(app, reporter):
                         if _is_splunk_defined_conf(filename):
                             lineno = conf.get_section(section_name).lineno
                             reporter_output = (
-                                "{0} stanza was found in {1}. "
+                                f"{section_name} stanza was found in {file_path}. "
                                 "Please remove any [default], [general], [global] stanzas or properties "
                                 "outside of a stanza (treated as default/global) "
                                 "from conf files defined by Splunk."
                                 "These stanzas/properties are not permitted "
                                 "because they modify global settings outside the context of the app."
-                                "File: {1}, Line: {2}."
-                            ).format(section_name, file_path, lineno)
+                                f"File: {file_path}, Line: {lineno}."
+                            )
                             reporter.fail(reporter_output, file_path, lineno)
             except Exception as error:
                 logger.error("unexpected error occurred: %s", str(error))
@@ -140,13 +140,12 @@ def check_inputs_conf_for_global_settings(app, reporter):
                     global_stanza_name
                 ).items():
                     reporter_output = (
-                        "The `{}/inputs.conf` specifies"
+                        f"The `{directory}/inputs.conf` specifies"
                         " global settings. These are prohibited in"
                         " Splunk Cloud instances. Please remove this"
                         " functionality."
-                        " Property: {} = {}. File: {}, Line: {}."
-                    ).format(
-                        directory, option_name, option_value, file_path, option_lineno
+                        f" Property: {option_name} = {option_value}."
+                        f" File: {file_path}, Line: {option_lineno}."
                     )
                     reporter.fail(reporter_output, file_path, option_lineno)
     else:
@@ -180,7 +179,7 @@ def check_manipulation_outside_of_app_container(app, reporter):
     for directory, filename, _ in app.iterate_files(
         types=[".conf"], basedir=["default", "local"]
     ):
-        if not filename in conf_check_list:
+        if filename not in conf_check_list:
             continue
         conf = app.get_config(filename, dir=directory)
         for section in conf.sections():
@@ -189,7 +188,7 @@ def check_manipulation_outside_of_app_container(app, reporter):
                 key = option.name
                 value = option.value
                 lineno = option.lineno
-                if not key in conf_check_list[filename]:
+                if key not in conf_check_list[filename]:
                     continue
                 for path in conf_parameter_arg_regex.findall(value):
                     if app_util.is_manipulation_outside_of_app_container(
@@ -221,7 +220,7 @@ def check_collections_conf_for_specified_name_field_type(app, reporter):
                     reporter_output = (
                         "The field type for filed.<name> in collections.conf includes"
                         " `number|bool|string|time`, use bool to instead of boolean"
-                        " Stanza: [{}]."
-                        " File: {}, Line: {}."
-                    ).format(section.name, filename, lineno)
+                        f" Stanza: [{section.name}]."
+                        f" File: {filename}, Line: {lineno}."
+                    )
                     reporter.fail(reporter_output, filename, lineno)
