@@ -2,10 +2,11 @@
 ### jQuery vulnerabilities
 """
 import os
-import re
+
 import splunk_appinspect
 import splunk_appinspect.check_routine.util as util
 
+
 """ This function throws a warning message during app inspect if the dashboards of the app
 do not have a version attribute OR have the version attribute set to a value other than 1.1
 
@@ -14,7 +15,7 @@ app: An app object
 reporter: Reporter object """
 
 
-@splunk_appinspect.tags("cloud", "jquery", "private_app", "future")
+@splunk_appinspect.tags("cloud", "jquery", "private_app")
 @splunk_appinspect.cert_version(min="2.5.0")
 def check_simplexml_standards_version(app, reporter):
     """Check that the dashboards in your app have a valid version attribute."""
@@ -24,10 +25,10 @@ def check_simplexml_standards_version(app, reporter):
         version = query_node.get("version")
         if version is None:
             message = (
-                "Change the version attribute in the root node of your Simple XML dashboard {} to "
-                + "`<version=1.1>`. Earlier dashboard versions introduce security vulnerabilities "
-                + "into your apps and are not permitted in Splunk Cloud"
-            ).format(relative_filepath)
+                "Change the version attribute in the root node of your Simple XML dashboard "
+                f"{relative_filepath} to `<version=1.1>`. Earlier dashboard versions introduce "
+                "security vulnerabilities into your apps and are not permitted in Splunk Cloud"
+            )
             reporter.fail(message, relative_filepath)
         elif (
             version.strip() == "2" or version.strip() == "1.1"
@@ -35,11 +36,12 @@ def check_simplexml_standards_version(app, reporter):
             continue
         else:
             message = (
-                "Version attribute of the dashboard {} is set to {}.Change the version attribute "
-                + "in the root node of your Simple XML dashboard to "
-                + "`<version=1.1>`. Earlier dashboard versions introduce security vulnerabilities "
-                + "into your apps and are not permitted in Splunk Cloud"
-            ).format(relative_filepath, version)
+                f"Version attribute of the dashboard {relative_filepath} is "
+                f"set to {version}.Change the version attribute in the root "
+                "node of your Simple XML dashboard to `<version=1.1>`. "
+                "Earlier dashboard versions introduce security vulnerabilities "
+                "into your apps and are not permitted in Splunk Cloud"
+            )
             reporter.fail(message, relative_filepath)
 
 
@@ -51,7 +53,7 @@ app: An app object
 reporter: Reporter object """
 
 
-@splunk_appinspect.tags("cloud", "jquery", "private_app", "future")
+@splunk_appinspect.tags("cloud", "jquery", "private_app")
 @splunk_appinspect.cert_version(min="2.5.0")
 def check_hotlinking_splunk_web_libraries(app, reporter):
     """Check that the app files are not importing files directly from the
@@ -69,6 +71,10 @@ def check_hotlinking_splunk_web_libraries(app, reporter):
             __file__, "../../splunk/jquery_checks_data/disallowed_imports.json"
         )
     )
+    # Get list of risky imports from search head (risky_imports.json)
+    risky_imports_json_path = os.path.abspath(
+        os.path.join(__file__, "../../splunk/jquery_checks_data/risky_imports.json")
+    )
 
     with open(
         disallowed_json_path, "r", encoding="utf-8", errors="ignore"
@@ -76,7 +82,13 @@ def check_hotlinking_splunk_web_libraries(app, reporter):
         disallowed_modules_imports = util.populate_set_from_json(
             disallowed_modules_file
         )
+    with open(
+        risky_imports_json_path, "r", encoding="utf-8", errors="ignore"
+    ) as risky_imports_file:
+        risky_modules_imports = util.populate_set_from_json(risky_imports_file)
 
     # Check for SH imports in all JS files
-    file_list = util.validate_imports(unpacked_js_files, disallowed_modules_imports)
+    file_list = util.validate_imports(
+        unpacked_js_files, disallowed_modules_imports, risky_modules_imports
+    )
     util.communicate_bad_import_message(reporter, file_list)
