@@ -29,6 +29,79 @@ logger = logging.getLogger(__name__)
 
 report_display_order = 40
 
+
+@splunk_appinspect.tags("cloud", "manual", "ast")
+@splunk_appinspect.cert_version(min="1.7.0")
+def check_for_hidden_python_files(app, reporter):
+    """Check that there are no hidden python files included in the app."""
+    if platform.system() == "Windows":
+        for directory, file, _ in app.iterate_files(excluded_types=[".py"]):
+            current_file_relative_path = os.path.join(directory, file)
+            reporter_output = (
+                "Please manual check this "
+                "file to check if it is a hidden python file. "
+                f"File: {current_file_relative_path}"
+            )
+            reporter.manual_check(
+                reporter_output,
+                file_name=current_file_relative_path,
+            )
+    else:
+        client = app.python_analyzer_client
+        for filepath in client.get_hidden_python_files():
+            if six.PY2:
+                content = open(os.path.join(app.app_temp_dir, filepath), "rU").read()
+            else:
+                import chardet
+
+                byte_string = open(
+                    os.path.join(app.app_temp_dir, filepath), "rb"
+                ).read()
+                encoding = chardet.detect(byte_string)["encoding"]
+                content = open(
+                    os.path.join(app.app_temp_dir, filepath), "r", encoding=encoding
+                ).read()
+            content = re.sub("[\r\n]+", " ", content)
+
+            # this check only focus on python template code
+            network_patterns = "(urllib|socket|httplib|requests|smtplib|ftplib|nntplib|poplib|imaplib|telnetlib|gopherlib|xmlrpclib|SimpleHTTPServer|SimpleXMLRPCServer)"
+            system_modules = "(subprocess|shutil|os|sys|distutils|threading|multiprocessing|commands)"
+            from_import_modules = fr"from\s+import\s+{system_modules}"
+            import_modules = fr"import\s+{system_modules}"
+            file_manipulation = r"\.(read|write|open)"
+            possible_injection = r"(subclasses|__class__|config)\.(iteritems|items)\(\)"
+            patterns = [
+                network_patterns,
+                from_import_modules,
+                import_modules,
+                file_manipulation,
+                possible_injection,
+            ]
+            template_pairs = [("<%.*", ".*%>"), ("{{.*", ".*}}"), ("{%.*", ".*%}")]
+
+            for search_pattern in [
+                pair[0] + pattern + pair[1]
+                for pattern in patterns
+                for pair in template_pairs
+            ]:
+                if re.search(search_pattern, content):
+                    reporter_output = f"Hidden python script found. File: {filepath}"
+                    reporter.manual_check(reporter_output, file_name=filepath)
+                    break
+
+
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.cert_version(min="1.0.0")
+def check_for_compiled_python(app, reporter):
+    """Check that there are no `.pyc` or `.pyo` files included in the app."""
+    for directory, filename, _ in app.iterate_files(types=[".pyc", ".pyo"]):
+        current_file_relative_path = os.path.join(directory, filename)
+        reporter_output = (
+            f"A Compiled Python file was detected. File: {current_file_relative_path}"
+        )
+        reporter.fail(reporter_output, current_file_relative_path)
+
+
 @splunk_appinspect.tags("cloud", "ast", "private_app")
 @splunk_appinspect.cert_version(min="1.7.0")
 def check_for_possible_threading(app, reporter):
