@@ -4,17 +4,14 @@
 ### XML file standards
 """
 
-# Python Standard Libraries
+import logging
 import re
 import xml
 from xml.sax import make_parser
-import logging
 
-# Third-Party Libraries
 import bs4
 import six
 
-# Custom Libraries
 import splunk_appinspect
 
 logger = logging.getLogger(__name__)
@@ -39,9 +36,7 @@ def check_that_all_xml_files_are_well_formed(app, reporter):
         try:
             parse_xml(full_filepath)
         except (xml.sax.SAXException, ValueError):
-            reporter.fail(
-                "Invalid XML file: {}".format(relative_filepath), relative_filepath
-            )
+            reporter.fail(f"Invalid XML file: {relative_filepath}", relative_filepath)
 
 
 @splunk_appinspect.tags("splunk_appinspect", "cloud", "manual")
@@ -66,7 +61,7 @@ def check_for_xml_embedded_javascript(app, reporter):
         if script_elements:
             total_lines_of_code_output = 0
             for element in script_elements:
-                element_as_string = "{}".format(element)
+                element_as_string = f"{element}"
                 element_content_regex = re.compile(
                     ">(.*?)<.*(?:>)", re.DOTALL | re.IGNORECASE | re.MULTILINE
                 )
@@ -79,9 +74,9 @@ def check_for_xml_embedded_javascript(app, reporter):
             total_lines_of_code_output += len(cdata_script_elements)
             reporter_output = (
                 "Embedded JavaScript has been detected."
-                " Total line(s) of code found: {}."
-                " File: {}"
-            ).format(total_lines_of_code_output, relative_filepath)
+                f" Total line(s) of code found: {total_lines_of_code_output}."
+                f" File: {relative_filepath}"
+            )
             reporter.manual_check(reporter_output, relative_filepath)
 
 
@@ -138,11 +133,12 @@ def check_validate_no_event_handler(app, reporter):
         soup = bs4.BeautifulSoup(open(full_filepath, "rb"), "lxml-xml")
         elements = soup.find_all(has_global_event_handler_attribute)
         if elements:
-            elements_as_strings = ["{}".format(element) for element in elements]
+            elements_as_strings = [f"{element}" for element in elements]
+            elements = "".join(elements_as_strings)
             reporter_output = (
                 "A global event handler was detected in use."
                 " Please verify that this use is valid."
-                " Elements: {}"
-                " File: {}"
-            ).format("".join(elements_as_strings), relative_filepath)
+                f" Elements: {elements}"
+                f" File: {relative_filepath}"
+            )
             reporter.manual_check(reporter_output, relative_filepath)
