@@ -1,17 +1,13 @@
 """Command-line helpers in order to help with command-line presentation."""
 
-# Python Standard Libraries
 import collections
 
-# Third-Party Libraries
 import click
 import painter
 from six import iteritems
 
-# Custom Libraries
 import splunk_appinspect
 
-
 result_colors = collections.defaultdict(
     dict,
     {
@@ -49,23 +45,22 @@ def output_summary(summary, summary_header=None):
     if summary_header is None:
         click.echo("Summary:\n")
     else:
-        click.echo("{}:\n".format(summary_header))
+        click.echo(f"{summary_header}:\n")
 
     total = 0
     for key, value in iteritems(summary):
         total = total + value
-        click.echo(
-            click.style("{:>14}: {:>2}".format(key, str(value)), **result_colors[key])
-        )
+        click.echo(click.style(f"{key:>14}: {str(value):>2}", **result_colors[key]))
     click.echo("-" * 19)
-    click.echo("{:>14}: {:>2}".format("Total", str(total)))
+    total_str = "Total"
+    click.echo(f"{total_str:>14}: {str(total):>2}")
 
     click.echo()
 
     click.echo(
         click.style(
             "Please note that more issues could be found out later during the optional manual review process.",
-            **{"fg": "yellow"}
+            **{"fg": "yellow"},
         )
     )
 
@@ -91,9 +86,7 @@ def print_result_records(
         max_messages = splunk_appinspect.main.MAX_MESSAGES_DEFAULT
     if max_messages == splunk_appinspect.main.MAX_MESSAGES_DEFAULT:
         click.echo(
-            "A default value of {0} for max-messages will be used.".format(
-                str(max_messages)
-            )
+            f"A default value of {str(max_messages)} for max-messages will be used."
         )
 
     for grouping in application_validation_report.groups():
@@ -118,12 +111,13 @@ def print_result_records(
                 click.echo(formatted_check_documentation)
                 for report_record in reporter.report_records(max_records=max_messages):
                     if report_record.result in message_types:
+                        format_string = format_cli_string(
+                            report_record.message, left_padding=12
+                        ).lstrip()
+
                         fmt = result_colors[report_record.result]
-                        result_message = "        {}: {}".format(
-                            report_record.result.upper(),
-                            format_cli_string(
-                                report_record.message, left_padding=12
-                            ).lstrip(),
+                        result_message = (
+                            f"        {report_record.result.upper()}: {format_string}"
                         )
                         click.secho(result_message, **fmt)
 
