@@ -1,21 +1,20 @@
 # Copyright 2019 Splunk Inc. All rights reserved.
 """Splunk conf file abstraction base module"""
-
-# Python Standard Libraries
 import re
+
 from six import iteritems
 
 
 class NoSectionError(Exception):
-    """ Exception raised when a specified section is not found. """
+    """Exception raised when a specified section is not found."""
 
 
 class NoOptionError(Exception):
-    """ Exception raised when a specified option is not found in the specified section. """
+    """Exception raised when a specified option is not found in the specified section."""
 
 
 class DuplicateSectionError(Exception):
-    """ Exception raised if add_section() is called with the name of a section that is already present. """
+    """Exception raised if add_section() is called with the name of a section that is already present."""
 
 
 class ConfigurationSetting(object):
@@ -52,9 +51,7 @@ class ConfigurationSection(object):
         if optname in self.options:
             return self.options[optname]
 
-        error_output = ("No option '{}' exists in section '{}'").format(
-            optname, self.name
-        )
+        error_output = f"No option '{optname}' exists in section '{self.name}'"
         raise NoOptionError(error_output)
 
     def settings(self):
@@ -94,12 +91,12 @@ class ConfigurationFile(object):
 
             error_output = (
                 "The option does not exist in the section "
-                " searched. Section: {}"
-                " Option: '{}'"
-            ).format(key, sectionname)
+                f" searched. Section: {key}"
+                f" Option: '{sectionname}'"
+            )
             raise NoOptionError(error_output)
         else:
-            raise NoSectionError("No section '{}' exists".format(sectionname))
+            raise NoSectionError(f"No section '{sectionname}' exists")
 
     def add_section(self, sectionname, header=None, lineno=None):
         section = ConfigurationSection(sectionname, header=header, lineno=lineno)
@@ -118,7 +115,7 @@ class ConfigurationFile(object):
         if sectionname in self.sects:
             return self.sects[sectionname]
 
-        raise NoSectionError("No such section: {}".format(sectionname))
+        raise NoSectionError(f"No such section: {sectionname}")
 
     def section_names(self):
         return self.sects.keys()
