@@ -4,13 +4,12 @@ Splunk AppInspect JUnit report formatter
 # Written by Aplura, LLC
 # Released under GPLv2
 
-# Third-Party Libraries
-import six
 from builtins import str as text
+
 import lxml.etree as et
+import six
 from lxml.etree import Element, SubElement  # noqa pylint: disable=no-name-in-module
 
-# Custom Libraries
 import splunk_appinspect
 from splunk_appinspect.formatters import validation_report_formatter
 
@@ -31,22 +30,27 @@ class ValidationReportJUnitXMLFormatter(
         summary = application_validation_report.get_summary()
         metrics = application_validation_report.metrics
 
+        summary_failure = summary["failure"]
+        summary_manual_check = summary["manual_check"]
+        summary_warning = summary["warning"]
+        summary_error = summary["error"]
+        summary_na = summary["not_applicable"]
+        summary_skipped = summary["skipped"]
+        summary_success = summary["success"]
+
+        metrics_execution_time = metrics["execution_time"]
+        metrics_start_time = metrics["start_time"].isoformat()
+
         testsuite_element_attributes = {
             "name": "Splunk AppInspect",
-            "failures": "{}".format(summary["failure"]),
-            "manual_checks": "{}".format(summary["manual_check"]),
-            "warnings": "{}".format(summary["warning"]),
-            "errors": "{}".format(summary["error"]),
-            "skipped": "{}".format(summary["not_applicable"] + summary["skipped"]),
-            "tests": "{}".format(
-                summary["skipped"]
-                + summary["not_applicable"]
-                + summary["success"]
-                + summary["failure"]
-                + summary["error"]
-            ),
-            "time": "{}".format(metrics["execution_time"]),
-            "timestamp": "{}".format(metrics["start_time"].isoformat()),
+            "failures": f"{summary_failure}",
+            "manual_checks": f"{summary_manual_check}",
+            "warnings": f"{summary_warning}",
+            "errors": f"{summary_error}",
+            "skipped": f"{summary_na}{summary_skipped}",
+            "tests": f"{summary_skipped}{summary_na}{summary_success}{summary_failure}{summary_error}",
+            "time": f"{metrics_execution_time}",
+            "timestamp": f"{metrics_start_time}",
         }
         testsuite_element = Element("testsuite", testsuite_element_attributes)
         testsuite_element.append(
