@@ -2,19 +2,16 @@
 """
 Splunk AppInspect certification events listeners/handlers for precert mode
 """
-
-# Python Standard Libraries
 import collections
 import logging
 import sys
 import threading
 
-# Third-Party Libraries
 import click
 import painter
 
-# Custom Libraries
 import splunk_appinspect
+
 from . import listener
 
 logger = logging.getLogger(__name__)
@@ -47,9 +44,7 @@ class CertStatusListener(listener.Listener):
 
         :param app (App) The app object representing the Splunk Application.
         """
-        command_line_output = ("Validating: {} Version: {}").format(
-            app.name, app.version
-        )
+        command_line_output = f"Validating: {app.name} Version: {app.version}"
         click.echo(command_line_output)
 
     def on_finish_check(self, check, reporter):
@@ -63,7 +58,7 @@ class CertStatusListener(listener.Listener):
             result = reporter.state()
             glyph = click.style(
                 splunk_appinspect.command_line_helpers.glyphs[result],
-                **splunk_appinspect.command_line_helpers.result_colors[result]
+                **splunk_appinspect.command_line_helpers.result_colors[result],
             )
 
             self.counts[result] += 1
@@ -73,12 +68,12 @@ class CertStatusListener(listener.Listener):
             elif result == "error":
                 self.exit_status += 1000
 
-            check_output = (u"[ {} ] - {} - {}").format(
-                glyph,
-                painter.paint.cyan(check.name),
-                splunk_appinspect.command_line_helpers.format_cli_string(
-                    check.doc(), left_padding=12
-                ).lstrip(),
+            format_string = splunk_appinspect.command_line_helpers.format_cli_string(
+                check.doc(), left_padding=12
+            ).lstrip()
+
+            check_output = (
+                f"[ {glyph} ] - {painter.paint.cyan(check.name)} - {format_string}"
             )
             click.echo(check_output)
 
@@ -103,7 +98,7 @@ class CertStatusListener(listener.Listener):
             message_types=message_types,
         )
         click.echo("\n")
-        summary_header = "{} Report Summary".format(app.name)
+        summary_header = f"{app.name} Report Summary"
         splunk_appinspect.command_line_helpers.output_summary(
             application_validation_report.get_summary(), summary_header=summary_header
         )
@@ -111,6 +106,5 @@ class CertStatusListener(listener.Listener):
 
     @staticmethod
     def on_enable_python_analyzer():
-        """Returns None
-        """
+        """Returns None"""
         click.echo("Enable Python analyzer.")
