@@ -3,22 +3,16 @@
 # Copyright 2019 Splunk Inc. All rights reserved.
 
 """The main splunk-appinspect command line entry point."""
-
-# Python Standard Libraries
 import collections
 import logging
 import sys
-import yaml
 
-# Third-Party Libraries
 import click
 import painter
 
-# Custom Libraries
 import splunk_appinspect
-from splunk_appinspect.infra import configure_logger
 from splunk_appinspect import feedback_file_generator
-
+from splunk_appinspect.infra import configure_logger
 
 # Commands
 DOCUMENTATION_COMMAND = "documentation"
@@ -45,20 +39,20 @@ INCLUDED_TAGS_OPTION = "--included-tags"
 INCLUDED_TAGS_OPTION_HELP_OUTPUT = (
     "This allows the ability to select checks"
     " to INCLUDE based on functionality. Use"
-    " `splunk-appinspect {0} {1}` to view"
+    f" `splunk-appinspect {LIST_COMMAND} {TAGS_LIST_TYPE}` to view"
     " all available tags. To include multiple"
-    " tags use `{2} <tag1> {2} <tag2>`..."
-).format(LIST_COMMAND, TAGS_LIST_TYPE, INCLUDED_TAGS_OPTION)
+    f" tags use `{INCLUDED_TAGS_OPTION} <tag1> {INCLUDED_TAGS_OPTION} <tag2>`..."
+)
 
 
 EXCLUDED_TAGS_OPTION = "--excluded-tags"
 EXCLUDED_TAGS_OPTION_HELP_OUTPUT = (
     "This allows the ability to select checks"
     " to EXCLUDE based on functionality. Use"
-    " `splunk-appinspect {0} {1}` to view"
+    f" `splunk-appinspect {LIST_COMMAND} {TAGS_LIST_TYPE}` to view"
     " all available tags. To include multiple"
-    " tags use `{2} <tag1> {2} <tag2>`..."
-).format(LIST_COMMAND, TAGS_LIST_TYPE, EXCLUDED_TAGS_OPTION)
+    f" tags use `{EXCLUDED_TAGS_OPTION} <tag1> {EXCLUDED_TAGS_OPTION} <tag2>`..."
+)
 
 
 CUSTOM_CHECKS_DIR_OPTION = "--custom-checks-dir"
@@ -77,16 +71,16 @@ MODE_OPTION_HELP_OUTPUT = (
     "This allows the ability to specify different"
     " run-time output when performing an inspect"
     " validation."
-    "\n`{0}` - Returns muted output, providing more"
+    f"\n`{TEST_MODE}` - Returns muted output, providing more"
     " information relevant to unit testing. `.`"
     " represents success, and `F` represents failure."
     " Manual results are ignored by default. To enable"
     " manual results in this mode use the"
     " `--included-tags manual` option."
-    "\n`{1}` - Returns verbose output providing"
+    f"\n`{PRECERT_MODE}` - Returns verbose output providing"
     " more information relevant to Splunk"
-    " Certification. [default: `{0}`]"
-).format(TEST_MODE, PRECERT_MODE)
+    f" Certification. [default: `{TEST_MODE}`]"
+)
 
 
 OUTPUT_FILE_OPTION = "--output-file"
@@ -102,8 +96,8 @@ JUNIT_XML_DATA_FORMAT = "junitxml"
 DATA_FORMAT_OPTION_HELP_OUTPUT = (
     "This allows the ability to specify the data"
     " format of the Splunk AppInspect output."
-    " [default: `{}`]"
-).format(JSON_DATA_FORMAT)
+    f" [default: `{JSON_DATA_FORMAT}`]"
+)
 
 LOG_LEVEL_OPTION = "--log-level"
 NOTSET_LOG_LEVEL = logging.getLevelName(logging.NOTSET)  # "NOTSET"
@@ -115,8 +109,8 @@ CRITICAL_LOG_LEVEL = logging.getLevelName(logging.CRITICAL)  # "CRITICAL"
 LOG_LEVEL_OPTION_HELP_OUTPUT = (
     "This allows the ability to specify the log"
     " level for Python's logging library."
-    " [default: `{}`]"
-).format(CRITICAL_LOG_LEVEL)
+    f" [default: `{CRITICAL_LOG_LEVEL}`]"
+)
 
 LOG_FILE_OPTION = "--log-file"
 LOG_FILE_OPTION_HELP_OUTPUT = (
@@ -129,8 +123,8 @@ MAX_MESSAGES_DEFAULT = 25
 MAX_MESSAGES_OPTION_HELP_OUTPUT = (
     "This allows the ability to configure AppInspect to return as much or as little"
     " information as desired."
-    " [default: `{}`]"
-).format(MAX_MESSAGES_DEFAULT)
+    f" [default: `{MAX_MESSAGES_DEFAULT}`]"
+)
 
 GENERATE_FEEDBACK_OPTION = "--generate-feedback"
 GENERATE_FEEDBACK_OPTION_HELP_OUTPUT = "This allows the ability to generate a .inspect.yml file containing each instance of a manual or failure check."
@@ -176,17 +170,15 @@ class MaxMessagesParamType(click.ParamType):
                 return int(value)
             else:
                 self.fail(
-                    '"{}" is not a valid value for max-messages. Only positive integers or "all" are valid for this parameter.'.format(
-                        value
-                    ),
+                    f'"{value}" is not a valid value for max-messages. '
+                    'Only positive integers or "all" are valid for this parameter.',
                     param,
                     ctx,
                 )
         except ValueError:
             self.fail(
-                '"{}" is not a valid value for max-messages. Only positive integers or "all" are valid for this parameter.'.format(
-                    value
-                ),
+                f'"{value}" is not a valid value for max-messages. '
+                'Only positive integers or "all" are valid for this parameter.',
                 param,
                 ctx,
             )
@@ -254,13 +246,16 @@ def documentation(
             pass
 
     if CRITERIA_DOCUMENTATION_TYPE in documentation_types:
-        html_markup_criteria = splunk_appinspect.documentation.criteria_generator.generate_critera_as_html(
-            included_tags, excluded_tags, custom_checks_dir
+        html_markup_criteria = (
+            splunk_appinspect.documentation.criteria_generator.generate_critera_as_html(
+                included_tags, excluded_tags, custom_checks_dir
+            )
         )
         # TODO: Do we want this to also support json?
         # Print to standard stream if no output file provided
         if output_file is None:
-            click.echo("{} HTML CRITERIA CONTENT {}".format("=" * 20, "=" * 20))
+            format_str = "=" * 20
+            click.echo(f"{format_str} HTML CRITERIA CONTENT {format_str}")
             click.echo(html_markup_criteria)
         # Print to file
         else:
@@ -275,7 +270,8 @@ def documentation(
         # TODO: Do we want this to also support json?
         # Print to standard stream if no output file provided
         if output_file is None:
-            click.echo("{} HTML TAG REFERENCE {}".format("=" * 20, "=" * 20))
+            format_str = "=" * 20
+            click.echo(f"{format_str} HTML TAG REFERENCE {format_str}")
             click.echo(html_markup_tag_reference)
         # Print to file
         else:
@@ -298,12 +294,10 @@ def documentation(
             invalid_tags_found.append(tag_provided_by_the_user)
 
     for invalid_tag_found in invalid_tags_found:
-        unexpected_tag_output = ("Unexpected tag provided: {}").format(
-            invalid_tag_found
-        )
+        unexpected_tag_output = f"Unexpected tag provided: {invalid_tag_found}"
         click_formatted_output = click.style(
-            "{}".format(unexpected_tag_output),
-            **splunk_appinspect.command_line_helpers.result_colors["error"]
+            f"{unexpected_tag_output}",
+            **splunk_appinspect.command_line_helpers.result_colors["error"],
         )
         click.echo(click_formatted_output)
 
@@ -316,17 +310,19 @@ def documentation(
     ]
     for unexpected_documentation_type in unexpected_documentation_types:
         unexpected_documentation_type_output = (
-            "Unexpected documentation-type detected: {}"
-        ).format(unexpected_documentation_type)
+            f"Unexpected documentation-type detected: {unexpected_documentation_type}"
+        )
         click.echo(
             click.style(
-                "{}".format(unexpected_documentation_type_output),
-                **splunk_appinspect.command_line_helpers.result_colors["error"]
+                f"{unexpected_documentation_type_output}",
+                **splunk_appinspect.command_line_helpers.result_colors["error"],
             )
         )
 
 
-@report_cli.command(LIST_COMMAND, short_help="List information about Splunk AppInspect")
+@report_cli.command(  # noqa: C901
+    LIST_COMMAND, short_help="List information about Splunk AppInspect"
+)
 @click.argument(LIST_TYPE_ARGUMENT, nargs=-1, required=True)
 @click.option(
     INCLUDED_TAGS_OPTION,
@@ -359,26 +355,28 @@ def report(list_type, included_tags, excluded_tags, custom_checks_dir):
 
     def create_header(header_title, header_column_length=80):
         horizontal_line_rule = "=" * header_column_length
-        return "\n{0}\n{1}\n{0}".format(horizontal_line_rule, header_title)
+        return f"\n{horizontal_line_rule}\n{header_title}\n{horizontal_line_rule}"
 
     def print_group_checks(group):
         for check in group.checks():
-            check_name_output = ("{}- {} {}").format(
-                " " * 4, painter.paint.cyan("Name:"), check.name
-            )
-            check_documentation_output = ("{}- {} {}").format(
-                " " * 8,
-                painter.paint.cyan("Description:"),
-                splunk_appinspect.command_line_helpers.format_cli_string(
-                    check.doc(), left_padding=20
-                ).lstrip(),
-            )
-            check_version_output = ("{}- {} {}").format(
-                " " * 8, painter.paint.cyan("Version:"), check.version_doc()
-            )
-            check_tag_output = ("{}- {} {}").format(
-                " " * 8, painter.paint.cyan("Tags:"), ", ".join(check.tags)
+            check_name_str = " " * 4
+            check_str = " " * 8
+            paint_name = painter.paint.cyan("Name:")
+            paint_description = painter.paint.cyan("Description:")
+            paint_version = painter.paint.cyan("Version:")
+            paint_tag = painter.paint.cyan("Tags:")
+            check_tag_str = ", ".join(check.tags)
+
+            format_string = splunk_appinspect.command_line_helpers.format_cli_string(
+                check.doc(), left_padding=20
+            ).lstrip()
+
+            check_name_output = f"{check_name_str}- {paint_name} {check.name}"
+            check_documentation_output = (
+                f"{check_str}- {paint_description} {format_string}"
             )
+            check_version_output = f"{check_str}- {paint_version} {check.version_doc()}"
+            check_tag_output = f"{check_str}- {paint_tag} {check_tag_str}"
             click.echo(check_name_output)
             click.echo(check_documentation_output)
             click.echo(check_version_output)
@@ -390,11 +388,9 @@ def report(list_type, included_tags, excluded_tags, custom_checks_dir):
             return
         for group in groups_iterator:
             if GROUPS_LIST_TYPE in list_type:
-                group_name_output = "{}".format(painter.paint.green(group.name))
-                group_doc_output = "{}".format(painter.paint.yellow(group.doc()))
-                group_header_output = "{} ({})".format(
-                    group_doc_output, group_name_output
-                )
+                group_name_output = f"{painter.paint.green(group.name)}"
+                group_doc_output = f"{painter.paint.yellow(group.doc())}"
+                group_header_output = f"{group_doc_output} ({group_name_output})"
                 click.echo(group_header_output)
 
             if CHECKS_LIST_TYPE in list_type:
@@ -411,9 +407,7 @@ def report(list_type, included_tags, excluded_tags, custom_checks_dir):
     )
     # Print Version Here:
     if VERSION_LIST_TYPE in list_type:
-        click.echo(
-            "Splunk AppInspect Version {}".format(splunk_appinspect.version.__version__)
-        )
+        click.echo(f"Splunk AppInspect Version {splunk_appinspect.version.__version__}")
 
     # Print Standard Checks here
     if CHECKS_LIST_TYPE in list_type:
@@ -433,13 +427,10 @@ def report(list_type, included_tags, excluded_tags, custom_checks_dir):
         click.echo(create_header("Group Metrics"))
         standard_group_count = len(list(standard_groups_iterator))
         custom_group_count = len(list(custom_groups_iterator))
-        click.echo("Standard Groups Count: {:>2}".format(standard_group_count))
-        click.echo("Custom Groups Count:   {:>2}".format(custom_group_count))
-        click.echo(
-            "Total Groups Count:    {:>2}".format(
-                standard_group_count + custom_group_count
-            )
-        )
+        click.echo(f"Standard Groups Count: {standard_group_count:>2}")
+        click.echo(f"Custom Groups Count:   {custom_group_count:>2}")
+        group_count = standard_group_count + custom_group_count
+        click.echo(f"Total Groups Count:    {group_count:>2}")
     # Print Check Metrics Here
     if CHECKS_LIST_TYPE in list_type:
         click.echo(create_header("Check Metrics"))
@@ -451,13 +442,10 @@ def report(list_type, included_tags, excluded_tags, custom_checks_dir):
         ]
         standard_check_count = len(standard_checks)
         custom_check_count = len(custom_checks)
-        click.echo("Standard Checks Count: {}".format(standard_check_count))
-        click.echo("Custom Checks Count:   {}".format(custom_check_count))
-        click.echo(
-            "Total Checks Count:    {}".format(
-                standard_check_count + custom_check_count
-            )
-        )
+        click.echo(f"Standard Checks Count: {standard_check_count}")
+        click.echo(f"Custom Checks Count:   {custom_check_count}")
+        check_count = standard_check_count + custom_check_count
+        click.echo(f"Total Checks Count:    {check_count}")
 
     # Print Tags here
     if TAGS_LIST_TYPE in list_type:
@@ -487,13 +475,13 @@ def report(list_type, included_tags, excluded_tags, custom_checks_dir):
         l_type for l_type in list_type if l_type not in VALID_VALUES[LIST_TYPE_ARGUMENT]
     ]
     for unexpected_list_type in unexpected_list_types:
-        unexpected_list_type_output = ("Unexpected list-type detected: {}").format(
-            unexpected_list_type
+        unexpected_list_type_output = (
+            f"Unexpected list-type detected: {unexpected_list_type}"
         )
         click.echo(
             click.style(
-                "{}".format(unexpected_list_type_output),
-                **splunk_appinspect.command_line_helpers.result_colors["error"]
+                f"{unexpected_list_type_output}",
+                **splunk_appinspect.command_line_helpers.result_colors["error"],
             )
         )
 
