@@ -1,8 +1,6 @@
-# Python Standard Libraries
 import ast
 from collections import deque
 
-# Third-Party Libraries
 from six import iteritems
 
 
@@ -56,8 +54,8 @@ class AstInfoQuery(object):
 
     def is_end(self):
         """
-            If is_end is true, it means last operation has no effect, otherwise last
-            operation is performed successfully
+        If is_end is true, it means last operation has no effect, otherwise last
+        operation is performed successfully
         """
         return self._is_end
 
@@ -142,9 +140,7 @@ class AstInfoQuery(object):
             if isinstance(filter_logic_node, And):
                 return left_set & right_set
 
-            raise Exception(
-                "Unknown BinaryLogicNode {}".format(type(filter_logic_node))
-            )
+            raise Exception(f"Unknown BinaryLogicNode {type(filter_logic_node)}")
         if isinstance(filter_logic_node, MultiLogicNode):
             if isinstance(filter_logic_node, (MultiOr, MultiAnd)):
                 if filter_logic_node.nodes:
@@ -167,9 +163,7 @@ class AstInfoQuery(object):
                     "At least one element should be included in MultiLogicNode"
                 )
 
-            raise Exception(
-                "Unknown MultiBinaryLogicNode {}".format(type(filter_logic_node))
-            )
+            raise Exception(f"Unknown MultiBinaryLogicNode {type(filter_logic_node)}")
         if isinstance(filter_logic_node, DataSetNode):
             if isinstance(filter_logic_node, Any):
                 return self._get_next_batch_candidates_for_any(
@@ -180,17 +174,15 @@ class AstInfoQuery(object):
                     all_node_set, filter_logic_node.node_set
                 )
 
-            raise Exception("Unknown DataSetNode {}".format(type(filter_logic_node)))
+            raise Exception(f"Unknown DataSetNode {type(filter_logic_node)}")
         if isinstance(filter_logic_node, SingleLogicNode):
             if isinstance(filter_logic_node, Not):
                 result_set = self._post_traverse(filter_logic_node.child, all_node_set)
                 return all_node_set - result_set
 
-            raise Exception(
-                "Unknown SingleLogicNode {}".format(type(filter_logic_node))
-            )
+            raise Exception(f"Unknown SingleLogicNode {type(filter_logic_node)}")
 
-        raise Exception("Unsupported Node {}".format(type(filter_logic_node)))
+        raise Exception(f"Unsupported Node {type(filter_logic_node)}")
 
     def _get_next_batch_candidates_for_any(self, all_node_set, logic_node_set):
         result_set = set()
