@@ -1,24 +1,19 @@
 """
 Splunk App python file dependency manager module
 """
-# Python Standard Libraries
-import os
+import ast
 import itertools
 import logging
-import ast
+import multiprocessing
+import os
 import platform
 import shutil
-import multiprocessing
 from lib2to3.main import main as exec_two_to_three
 
-# Third-Party Libraries
 import six
 from six import iteritems
 
-# Custom Libraries
-from splunk_appinspect.python_analyzer import utilities
-from splunk_appinspect.python_analyzer import ast_types
-
+from splunk_appinspect.python_analyzer import ast_types, utilities
 
 if not platform.system() == "Windows":
     import magic
@@ -175,18 +170,18 @@ class FileDepManager(object):
 
     def iter_non_circular_dependency_files(self):
         r"""
-            Assume the file_pool is [a.py, b.py, c.py, d.py, e.py],
-            whereas we have the following dependencies:
+        Assume the file_pool is [a.py, b.py, c.py, d.py, e.py],
+        whereas we have the following dependencies:
 
-                     a.py        d.py      e.py
-                    /   \       /
-                   /     \     /
-                b.py       c.py
+                 a.py        d.py      e.py
+                /   \       /
+               /     \     /
+            b.py       c.py
 
-                    The lower depend on the upper
+                The lower depend on the upper
 
-            The iterating order would be [a.py, b.py, d.py, c.py, e.py].
-            Make sure to visit all its parents first before visit a node.
+        The iterating order would be [a.py, b.py, d.py, c.py, e.py].
+        Make sure to visit all its parents first before visit a node.
         """
         stack = []
         changeable_in_degree = {}
@@ -250,11 +245,11 @@ class FileDepManager(object):
 
     def add_file(self, filepath):
         """
-            A file tree would be established based on the file's dependencies
+        A file tree would be established based on the file's dependencies
         """
         filepath = os.path.abspath(filepath)
         if not os.path.isfile(filepath):
-            raise Exception("{} not found or isn't file".format(filepath))
+            raise Exception(f"{filepath} not found or isn't file")
         if filepath in self._file_pool:
             return self._file_pool[filepath]
 
@@ -287,7 +282,7 @@ class FileDepManager(object):
                         )
                     # retry find_imports again
                     deps = utilities.find_imports(filepath, self.libs)
-                except:
+                except Exception:
                     self._syntax_error_file.add(filepath)
                     return None
         except (TypeError, ValueError):
@@ -336,12 +331,17 @@ class FileDepManager(object):
                 else:
                     # check if it is hidden python file
                     window_filter_exts = [".conf"]
+                    is_windows = platform.system() == "Windows"
+                    if not is_windows:
+                        mime_type = magic.from_file(file_path, mime=True).lower()
                     if (
-                        not platform.system() == "Windows"
-                        and magic.from_file(file_path, mime=True).lower()
-                        == "text/x-python"
+                        not is_windows
+                        and (
+                            mime_type == "text/x-python"
+                            or mime_type == "text/x-script.python"
+                        )
                     ) or (
-                        platform.system() == "Windows"
+                        is_windows
                         and (
                             not any(
                                 map(
@@ -355,7 +355,7 @@ class FileDepManager(object):
                             ast.parse(open(file_path, mode="rb").read())
                             counter += 1
                             self.add_file(file_path)
-                        except:
+                        except Exception:
                             # try 2to3 when py version is three
                             if not six.PY2:
                                 try:
@@ -390,7 +390,7 @@ class FileDepManager(object):
                                     ast.parse(open(file_path, mode="rb").read())
                                     counter += 1
                                     self.add_file(file_path)
-                                except:
+                                except Exception:
                                     # 2to3 parser and python3 parser are more stricter
                                     # stored in syntax error file to guarantee we won't leave it out
                                     if file_path.endswith(".py"):
