@@ -1,11 +1,14 @@
 import os
 import re
 from abc import ABCMeta, abstractmethod
+
 from bs4 import BeautifulSoup
 
-from splunk_appinspect.regex_matcher import RegexMatcher
-from splunk_appinspect.regex_matcher import JSReflectedXSSMatcher
-from splunk_appinspect.regex_matcher import RegexBundle
+from splunk_appinspect.regex_matcher import (
+    JSReflectedXSSMatcher,
+    RegexBundle,
+    RegexMatcher,
+)
 
 
 class ReflectedXSSDetector:
@@ -136,12 +139,10 @@ class InputTextValueUsedInJavascript(ReflectedXSSDetectRule):
             if len(result_list) < 200:
                 for result in result_list:
                     reporter_output = (
-                        "{}. The following line will be inspected during code review."
-                        " Match: {}"
-                        " File: {}"
-                        " Line: {}"
-                    ).format(
-                        self.rule_description, result[2].strip(), result[0], result[1]
+                        f"{self.rule_description}. The following line will be inspected during code review."
+                        f" Match: {result[2].strip()}"
+                        f" File: {result[0]}"
+                        f" Line: {result[1]}"
                     )
                     ans.append((reporter_output, result[0], result[1]))
         return ans
@@ -167,13 +168,9 @@ class SimpleXMLVariableUsedInElementSource(ReflectedXSSDetectRule):
                         # only report one manual check for one element
                         if token in src_value:
                             reporter_output = (
-                                "{}. The following line will be inspected during code review."
-                                " Match: {}"
-                                " File: {}"
-                            ).format(
-                                self.rule_description,
-                                src_value,
-                                os.path.join(directory, f),
+                                f"{self.rule_description}. The following line will be inspected during code review."
+                                f" Match: {src_value}"
+                                f" File: {os.path.join(directory, f)}"
                             )
                             ans.append((reporter_output, os.path.join(directory, f)))
                             break
@@ -191,10 +188,10 @@ class UserJavascriptReflectedXSSDetectRule(ReflectedXSSDetectRule):
             for result in result_list:
                 reporter_output = (
                     "The following line will be inspected during code review."
-                    " Match: {}"
-                    " File: {}"
-                    " Line: {}"
-                ).format(result[1], os.path.join(directory, f), result[0])
+                    f" Match: {result[1]}"
+                    f" File: {os.path.join(directory, f)}"
+                    f" Line: {result[0]}"
+                )
                 ans.append((reporter_output, os.path.join(directory, f), result[0]))
         return ans
 
@@ -212,9 +209,9 @@ class UserHTMLReflectedXSSDetectRule(ReflectedXSSDetectRule):
 
         # report output template
         self.reporter_output = (
-            "{}. The following line will be inspected during code review."
-            " Match: {}"
-            " File: {}"
+            "{description}. The following line will be inspected during code review."
+            " Match: {value}"
+            " File: {filepath}"
         )
 
     def check(self, app):
@@ -243,10 +240,10 @@ class UserHTMLReflectedXSSDetectRule(ReflectedXSSDetectRule):
         attribute_value_pattern=None,
     ):
         """
-            attribute_name:          attribute we want to check
-            attr_dict:               attribute dictionary we work on
-            attribute_name_pattern:  attribute name need to match this pattern if exists
-            attribute_value_pattern: attribute value need to match this pattern if exists
+        attribute_name:          attribute we want to check
+        attr_dict:               attribute dictionary we work on
+        attribute_name_pattern:  attribute name need to match this pattern if exists
+        attribute_value_pattern: attribute value need to match this pattern if exists
         """
         if attribute_name in attr_dict:
             attribute_value = attr_dict[attribute_name]
@@ -276,7 +273,9 @@ class DefaultSrcTagToGetPastFiltersThatCheckSrcDomain(UserHTMLReflectedXSSDetect
                     ans.append(
                         (
                             self.reporter_output.format(
-                                self.rule_description, attr_value, current_file_path
+                                description=self.rule_description,
+                                value=attr_value,
+                                filepath=current_file_path,
                             ),
                             current_file_path,
                         )
@@ -297,7 +296,9 @@ class DefaultSrcTagByLeavingItEmpty(UserHTMLReflectedXSSDetectRule):
                     ans.append(
                         (
                             self.reporter_output.format(
-                                self.rule_description, attr_value, current_file_path
+                                description=self.rule_description,
+                                value=attr_value,
+                                filepath=current_file_path,
                             ),
                             current_file_path,
                         )
@@ -319,7 +320,9 @@ class DefaultSrcTagByLeavingItOutEntirely(UserHTMLReflectedXSSDetectRule):
                         ans.append(
                             (
                                 self.reporter_output.format(
-                                    self.rule_description, attr_value, current_file_path
+                                    description=self.rule_description,
+                                    value=attr_value,
+                                    filepath=current_file_path,
                                 ),
                                 current_file_path,
                             )
@@ -340,9 +343,9 @@ class ImageXSSOnErrorAlert(UserHTMLReflectedXSSDetectRule):
                     ans.append(
                         (
                             self.reporter_output.format(
-                                self.rule_description,
-                                attr_dict["onerror"],
-                                current_file_path,
+                                description=self.rule_description,
+                                value=attr_dict["onerror"],
+                                filepath=current_file_path,
                             ),
                             current_file_path,
                         )
@@ -363,9 +366,9 @@ class ImageXSSUsingJavascriptDirective(UserHTMLReflectedXSSDetectRule):
                     ans.append(
                         (
                             self.reporter_output.format(
-                                self.rule_description,
-                                attr_dict["src"],
-                                current_file_path,
+                                description=self.rule_description,
+                                value=attr_dict["src"],
+                                filepath=current_file_path,
                             ),
                             current_file_path,
                         )
@@ -386,9 +389,9 @@ class ImageDynsrc(UserHTMLReflectedXSSDetectRule):
                     ans.append(
                         (
                             self.reporter_output.format(
-                                self.rule_description,
-                                attr_dict["dynsrc"],
-                                current_file_path,
+                                description=self.rule_description,
+                                value=attr_dict["dynsrc"],
+                                filepath=current_file_path,
                             ),
                             current_file_path,
                         )
@@ -409,9 +412,9 @@ class ImageLowsrc(UserHTMLReflectedXSSDetectRule):
                     ans.append(
                         (
                             self.reporter_output.format(
-                                self.rule_description,
-                                attr_dict["lowsrc"],
-                                current_file_path,
+                                description=self.rule_description,
+                                value=attr_dict["lowsrc"],
+                                filepath=current_file_path,
                             ),
                             current_file_path,
                         )
@@ -433,7 +436,9 @@ class MalformedATag(UserHTMLReflectedXSSDetectRule):
                         ans.append(
                             (
                                 self.reporter_output.format(
-                                    self.rule_description, attr_value, current_file_path
+                                    description=self.rule_description,
+                                    value=attr_value,
+                                    filepath=current_file_path,
                                 ),
                                 current_file_path,
                             )
@@ -456,9 +461,9 @@ class IframeAndFrameXSSCheck(UserHTMLReflectedXSSDetectRule):
                             ans.append(
                                 (
                                     self.reporter_output.format(
-                                        self.rule_description,
-                                        attr_value,
-                                        current_file_path,
+                                        description=self.rule_description,
+                                        value=attr_value,
+                                        filepath=current_file_path,
                                     ),
                                     current_file_path,
                                 )
@@ -470,9 +475,9 @@ class IframeAndFrameXSSCheck(UserHTMLReflectedXSSDetectRule):
                         ans.append(
                             (
                                 self.reporter_output.format(
-                                    self.rule_description,
-                                    attr_dict["src"],
-                                    current_file_path,
+                                    description=self.rule_description,
+                                    value=attr_dict["src"],
+                                    filepath=current_file_path,
                                 ),
                                 current_file_path,
                             )
@@ -493,9 +498,9 @@ class InputTypeImageXSSCheck(UserHTMLReflectedXSSDetectRule):
                     ans.append(
                         (
                             self.reporter_output.format(
-                                self.rule_description,
-                                attr_dict["src"],
-                                current_file_path,
+                                description=self.rule_description,
+                                value=attr_dict["src"],
+                                filepath=current_file_path,
                             ),
                             current_file_path,
                         )
@@ -515,10 +520,10 @@ class BodyTagXSSCheck(UserHTMLReflectedXSSDetectRule):
                 ):
                     ans.append(
                         (
-                            self.reporter_output.format(
-                                self.rule_description,
-                                attr_dict["onload"],
-                                current_file_path,
+                            self.reporter_output.foramt(
+                                description=self.rule_description,
+                                value=attr_dict["onload"],
+                                filepath=current_file_path,
                             ),
                             current_file_path,
                         )
@@ -530,9 +535,9 @@ class BodyTagXSSCheck(UserHTMLReflectedXSSDetectRule):
                     ans.append(
                         (
                             self.reporter_output.format(
-                                self.rule_description,
-                                attr_dict["background"],
-                                current_file_path,
+                                description=self.rule_description,
+                                value=attr_dict["background"],
+                                filepath=current_file_path,
                             ),
                             current_file_path,
                         )
@@ -555,9 +560,9 @@ class SvgTagXSSCheck(UserHTMLReflectedXSSDetectRule):
                 ans.append(
                     (
                         self.reporter_output.format(
-                            self.rule_description,
-                            attr_dict["onload"],
-                            current_file_path,
+                            description=self.rule_description,
+                            value=attr_dict["onload"],
+                            filepath=current_file_path,
                         ),
                         current_file_path,
                     )
@@ -580,9 +585,9 @@ class TableAndTdXSSCheck(UserHTMLReflectedXSSDetectRule):
                 ans.append(
                     (
                         self.reporter_output.format(
-                            self.rule_description,
-                            attr_dict["background"],
-                            current_file_path,
+                            description=self.rule_description,
+                            value=attr_dict["background"],
+                            filepath=current_file_path,
                         ),
                         current_file_path,
                     )
@@ -605,7 +610,9 @@ class LinkXSSCheck(UserHTMLReflectedXSSDetectRule):
                 ans.append(
                     (
                         self.reporter_output.format(
-                            self.rule_description, attr_dict["href"], current_file_path
+                            description=self.rule_description,
+                            value=attr_dict["href"],
+                            filepath=current_file_path,
                         ),
                         current_file_path,
                     )
@@ -631,7 +638,9 @@ class DivStyleSheetXSSCheck(UserHTMLReflectedXSSDetectRule):
                 ans.append(
                     (
                         self.reporter_output.format(
-                            self.rule_description, attr_dict["style"], current_file_path
+                            description=self.rule_description,
+                            value=attr_dict["style"],
+                            filepath=current_file_path,
                         ),
                         current_file_path,
                     )
