@@ -8,27 +8,25 @@ provide a mechanism to store and retrieve report records such that a completed
 validation check can be performed and provide detailed feedback for the errors
 encountered.
 """
-
-# Python Standard Library
+import codecs
 import collections
 import inspect
+import json
 import logging
-import string
-import traceback
-from datetime import datetime
 import os.path
 import re
-import json
-import codecs
-from functools import reduce
+import string
+import traceback
 from builtins import str as text
+from datetime import datetime
+from functools import reduce
 
-from six import iteritems
 import six
+from six import iteritems
 
 
 def unknown_char(e):
-    return u"?", e.end
+    return "?", e.end
 
 
 codecs.register_error("unknown_char", unknown_char)
@@ -119,7 +117,7 @@ class Reporter(object):
             counts = reduce(_reduce_record_summary, remainder, dict())
             summaries = []
             for status, count in iteritems(counts):
-                summaries.append("{} {} messages".format(count, status))
+                summaries.append(f"{count} {status} messages")
             text = ", ".join(summaries)
 
             # Used to respect to __save_result_message conventions
@@ -193,11 +191,10 @@ class Reporter(object):
         output_line_number = message_line_number or captured_line_number
 
         if output_file_name and not output_line_number:
-            return "{} File: {}".format(tailored_message, output_file_name)
+            return f"{tailored_message} File: {output_file_name}"
         if output_file_name and output_line_number:
-            return "{} File: {} Line Number: {}".format(
-                tailored_message, output_file_name, output_line_number
-            )
+            return f"{tailored_message} File: {output_file_name} Line Number: {output_line_number}"
+
         return tailored_message
 
     def warn(self, message, file_name=None, line_number=None):
